@@ -12,12 +12,6 @@ method_map = {
     'TRACE': 8,
 }
 
-framework_map = {
-    'FastAPI': 0,
-    'Flask': 1,
-}
-
 def log_request(json: dict):
     json['method'] = method_map[json['method']]
-    json['framework'] = framework_map[json['framework']]
     requests.post('https://api-analytics-server.vercel.app/api/log-request', json=json, timeout=5, verify=False)
